<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pa_PK">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>بارے</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="30"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="31"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Context menu option explanation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="40"/>
        <source>Make window stay on top of all other windows.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="43"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="51"/>
        <source>Version: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="57"/>
        <source>Logo designed by %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="59"/>
        <source>Built with Qt %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="60"/>
        <source>Source code</source>
        <translation>سروت دا کوڈ</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="70"/>
        <source>Contributors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="72"/>
        <source>List of contributors on GitHub</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="73"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="77"/>
        <source>Translators</source>
        <translation>ترجمے والے</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="78"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="122"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="146"/>
        <source>&amp;Special Thanks</source>
        <translation>شکریئے</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="148"/>
        <source>&amp;Third-party Libraries</source>
        <translation>تیجی پارٹی سوفٹویر</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="84"/>
        <source>Your Rights</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="54"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>%1 is released under the MIT License.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>This license grants people a number of freedoms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="88"/>
        <source>You are free to use %1, for any purpose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="89"/>
        <source>You are free to distribute %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="90"/>
        <source>You can study how %1 works and change it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="91"/>
        <source>You can distribute changed versions of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="121"/>
        <source>Third-party Libraries used by %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="144"/>
        <source>&amp;Help</source>
        <translation>مدد</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="145"/>
        <source>&amp;About</source>
        <translation>بارے</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="147"/>
        <source>&amp;License</source>
        <translation>لائیسنس</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../graphicsscene.cpp" line="90"/>
        <source>Drag image here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../graphicsview.cpp" line="338"/>
        <source>File url list is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="56"/>
        <source>File is not a valid image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="61"/>
        <location filename="../graphicsview.cpp" line="66"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="346"/>
        <source>Image data is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="353"/>
        <source>Not supported mimedata: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>File url list is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Copy</source>
        <translation>کاپی کرو</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Copy P&amp;ixmap</source>
        <translation>تصویر دا نقشہ کاپی کرو</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Copy &amp;File Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="119"/>
        <source>Properties</source>
        <translation>وشیشتاواں</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="39"/>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Stay on top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Protected mode</source>
        <translation>سرکھیات سیٹنگ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Zoom in</source>
        <translation>وڈا کرو</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Zoom out</source>
        <translation>چھوٹا کرو</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Flip &amp;Horizontally</source>
        <translation>لیٹویں اُلٹاؤ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="104"/>
        <source>&amp;Paste</source>
        <translation>پیسٹ کرو</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="93"/>
        <source>Toggle Checkerboard</source>
        <translation>چیک‌بورڈ چالو بدلو</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="87"/>
        <source>&amp;Open...</source>
        <translation>کھُلھو…</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="89"/>
        <source>Actual size</source>
        <translation>اصلی اکار</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>Toggle maximize</source>
        <translation>ودھو ودھ بدلو</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="94"/>
        <source>Rotate right</source>
        <translation>سجے گھنماؤ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="96"/>
        <source>Previous image</source>
        <translation>پچھلی تصویر</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Next image</source>
        <translation>اگلی تصویر</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="107"/>
        <source>Configure...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>Help</source>
        <translation>مدد</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Show in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="120"/>
        <source>Quit</source>
        <translation>بند کرو</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>تصویر دا میٹاڈیٹا</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="41"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>تصویر</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>فائل</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>کیمرہ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="33"/>
        <source>%1 File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="40"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>تفصیل</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>گی‌پی‌ایس</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="50"/>
        <source>Dimensions</source>
        <translation>ماپ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Aspect ratio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="56"/>
        <source>Frame count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="60"/>
        <source>Name</source>
        <translation>ناں</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Item type</source>
        <translation>قسم</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Folder path</source>
        <translation>فولڈر پاتھ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Size</source>
        <translation>اکار</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Date created</source>
        <translation>بݨاوݨ دی تریخ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="77"/>
        <source>Title</source>
        <translation>سرلیکھ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Subject</source>
        <translation>وِشا</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Rating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Tags</source>
        <translation>ٹیگ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Comments</source>
        <translation>ٹپݨیاں</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="88"/>
        <source>Authors</source>
        <translation>لیکھک</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Date taken</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="96"/>
        <source>Program name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Copyright</source>
        <translation>لائیسنس</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="101"/>
        <source>Horizontal resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Vertical resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Resolution unit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Colour representation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="110"/>
        <source>Camera maker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>F-stop</source>
        <translation>ایف سٹاپ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>Exposure time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>ISO speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>Exposure bias</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Focal length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Max aperture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Metering mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Subject distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Flash mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>35mm focal length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="135"/>
        <source>Lens model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Contrast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Brightness</source>
        <translation>چمک</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Exposure program</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Saturation</source>
        <translation>سنترپتہ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Sharpness</source>
        <translation>تکھاپن</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>White balance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>Digital zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>EXIF version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="154"/>
        <source>Latitude reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude</source>
        <translation>اکشانش</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Longitude reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude</source>
        <translation>لمبکار</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Altitude reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude</source>
        <translation>اُچائی</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="174"/>
        <source>%1 x %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="192"/>
        <source>%1 : %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Property</source>
        <translation>وشیشتا</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Value</source>
        <translation>مُل</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="21"/>
        <source>Settings</source>
        <translation>سیٹنگاں</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="26"/>
        <source>Do nothing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="27"/>
        <source>Close the window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="28"/>
        <source>Toggle maximize</source>
        <translation type="unfinished">ودھو ودھ بدلو</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="32"/>
        <source>Zoom in and out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>View next or previous item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Auto size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Maximized</source>
        <translation>ودھ توں ودھ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="56"/>
        <source>Stay on top when start-up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>Double-click behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="58"/>
        <source>Mouse wheel behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="59"/>
        <source>Default window size</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="38"/>
        <source>Pineapple Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>File list.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
